@@ -1,5 +1,5 @@
 package Task::FreecellSolver::Testing::MultiConfig;
-$Task::FreecellSolver::Testing::MultiConfig::VERSION = '0.0.1';
+$Task::FreecellSolver::Testing::MultiConfig::VERSION = '0.0.2';
 use warnings;
 use strict;
 
@@ -21,20 +21,30 @@ the Freecell Solver multi-config test suite.
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 TASK CONTENTS
 
 =head2 Freecell Solver deps
 
+=head3 L<App::Deps::Verify>
+
+=head3 L<App::Docmake>
+
+=head3 L<Code::TidyAll::Plugin::ClangFormat>
+
 =head3 L<Code::TidyAll::Plugin::ESLint>
 
+=head3 L<Code::TidyAll::Plugin::TSLint>
+
 =head3 L<Dist::Zilla::Plugin::Test::Kwalitee>
 
 =head3 L<Dist::Zilla::Plugin::Test::TidyAll>
 
 =head3 L<Dist::Zilla::PluginBundle::SHLOMIF>
 
+=head3 L<Pod::Weaver::PluginBundle::SHLOMIF>
+
 =head3 L<Pod::Weaver::Section::Support>
 
 =head3 L<HTML::Spelling::Site::Whitelist>
@@ -45,45 +55,14 @@ version 0.0.1
 
 =head3 L<Task::FreecellSolver::Testing>
 
-=head1 VERSION
-
-version 0.0.1
-
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/>
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2018 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/fc-solve/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Task::FreecellSolver::Testing::MultiConfig
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -101,14 +80,6 @@ L<https://metacpan.org/release/Task-FreecellSolver-Testing-MultiConfig>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Task-FreecellSolver-Testing-MultiConfig>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -117,22 +88,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Task-FreecellSolver-Testing-
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Task-FreecellSolver-Testing-MultiConfig>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Task-FreecellSolver-Testing-MultiConfig>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -181,4 +136,25 @@ L<https://github.com/shlomif/fc-solve>
 
   git clone git://github.com/shlomif/fc-solve.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/fc-solve/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
